# ANALIZADOR ESPECTRO UV V.1.2.4
# Programa para graficar los datos del Espectro UV/Vis
# a partir de los archivos .ascii
# Author: F. Javier Morales M.
# Date: 08/11/2021

# MODO DE EMPLEO
# Utilizar en el editor Atom con el paquete Hydrogen
# o en la linea de comandos con:
# >  ---WORK IN PRGESS!---

# CHANGELOG:
# 22/11/2021 - Creado el archivo como funciones para importar
# 25/11/2021 - Creada la clase spectroUV, módulos data_filter,data_plotter, save_plot
# 25/11/2021 - Corregido el index del DataFrame
# 26/11/2021 - Corregidas las funciones de area_plotter() y save_plot()

# TODO:
# [X] Crear función con parámetros de nombre de archivo
# [X] Pasar parametro de carpeta y filtro de archivos
# [X] Agregar dentro de la función los comandos para generar gráfico
# [X] Guardar gráfico en PDF
# [X] Importar funciones con import data_analysis
# [X] Crear una clase para generar objetos
# [X] Generar un archivo .csv
# [X] Crear librería/paquete y módulos
# [X] Agregar argumentos de funciones default
# [X] Agregar argumentos opcionales
# [] Subir paquete a Pypip



import pandas as pd
import numpy as np
from numpy import trapz
# from scipy.integrate import simps
from sklearn.linear_model import LinearRegression
import matplotlib.pyplot as plt
from IPython.display import display, Latex, Math
from os import listdir
import natsort as nsrt
import tkinter as tk
from tkinter import filedialog as fd
from laiiqa.helpers import *

# Mod 1.2.4
class SpectroUV:

    # def data_filter(self, filter):
    #     filtered_files = list()
    #     files = nsrt.natsorted(listdir())
    #     for i in files:
    #         if filter in i:
    #             filtered_files.append(i)
    #
    #     data = dict()
    #     data = {'Wavelenght': list(range(700, 199, -1))}
    #
    #     filtered_files = [s.split('.') for s in filtered_files]
    #     ext = filtered_files[0][1]
    #     filtered_files = [s.pop(0) for s in filtered_files]
    #
    #     for file_name in filtered_files:
    #         abscol = list()
    #         with open(file_name + '.' + ext, 'rb') as file:
    #             data.update({file_name: []})
    #             for i in range(88):
    #                 file.readline()
    #
    #             for line in file:
    #                 columns = line.strip().split()
    #                 abscol.append(float(columns[1]))
    #
    #             abs_array = np.array(abscol)
    #             data[file_name] = abs_array
    #             abscol = []
    #     # return data
    #     self.frameall = pd.DataFrame(data)
    #     self.spectro_plotter(visible=False)
    #     self.area_plotter(visible=False)


    def plot(self, filter='Filter', title='Espectro UV', subtitle=None, index='Wavelength', xlabel='Longitud de onda (nm)', ylabel='Absorbancia', x0=200, xf=None, y0=-0.05, yf=5.0, c0=0, cf=None, width=23, height=15, grid=True, visible=True):
        w = cm2in(width)
        h = cm2in(height)
        self.c0 = c0
        self.x0 = x0
        self.xf = xf
        filtered_files = list()
        files = nsrt.natsorted(listdir())
        for i in files:
            if filter in i:
                filtered_files.append(i)

        data = dict()
        data = {index: []}

        ext = filtered_files[0].rsplit('.', 1)[1]
        filtered_files = [s.rsplit('.', 1) for s in filtered_files]
        filtered_files = [s.pop(0) for s in filtered_files]
        # print(filtered_files)
        # print(ext)

        for file_name in filtered_files:
            wave = list()
            abscol = list()
            with open(file_name + '.' + ext, 'r') as file:
                data.update({file_name: []})
                for i in range(88):
                    file.readline()

                for line in file:
                    columns = line.strip().split()
                    wave.append(int(float(columns[0])))
                    abscol.append(float(columns[1]))

                wave_array = np.array(wave)
                abs_array = np.array(abscol)
                data[file_name] = abs_array
                data[index] = wave_array
                wave = []
                abscol = []
        # return data
        self.frameall = pd.DataFrame(data)
        # self.plot(visible=False)
        # self.area_plotter(visible=False)


        if index == 'Wavelength':
            self.frameall.index = data[index]
        elif index == None:
            self.frameall.index = self.frameall.index
        else:
            self.frameall.index = index


        if self.xf == None:
            self.xf = max(self.frameall.index)
        else:
            self.xf = self.xf

        if cf == None:
            cf = len(self.frameall.columns)
        else:
            cf = cf

        self.frame = self.frameall.iloc[max(self.frameall.index)-self.xf:max(self.frameall.index)+1-self.x0,self.c0:cf+1]
        fig = self.frame.plot(y=self.frame.columns[self.c0+1:cf+1], legend=True, figsize=(w, h), grid=grid)
        plt.suptitle(title, fontsize=14)
        fig.set_title(subtitle, fontsize=12)
        fig.set_xlim(self.x0, self.xf)
        fig.set_ylim(y0, yf)
        fig.set_xlabel(xlabel, fontsize=14)
        fig.set_ylabel(ylabel, fontsize=14)
        # plt.grid()
        self.figure = fig.get_figure()
        if visible == False:
            plt.close()
        else:
            plt.show()


    def plot_area(self, title='Espectro UV', subtitle='Area bajo la curva', xlabel='Tiempo (h)', ylabel='Area', labelx='Area', labely='y', width=23, height=15, dx=1.0, visible=True):
        w = cm2in(width)
        h = cm2in(height)

        if subtitle == 'Area bajo la curva':
            subtitle = f'Area bajo la curva ({self.x0} - {self.xf} nm)'
        else:
            subtitle = subtitle

        area = list()

        for i in range(self.c0+1,len(self.frame.columns)):
            area_trapz = trapz(y=self.frame.iloc[:,i], dx=dx)
            area.append(area_trapz)

        self.area_x = np.array(range(len(area))).reshape(-1,1)
        self.area_y = np.array(area)
        reg_line = LinearRegression()
        reg_line.fit(self.area_x.reshape(-1,1), self.area_y)
        self.Y_pred = reg_line.predict(self.area_x)
        # beta*x + alfa
        self.alfa = reg_line.intercept_
        self.beta = reg_line.coef_
        self.r_sq = reg_line.score(self.area_x, self.area_y)

        # plt.rcParams['text.usetex'] = True
        self.reg_equation = '$y = {0:.2f}x + {1:.2f}$\n $R^2 = {2:.4f}$'.format(float(self.beta),self.alfa,self.r_sq)
        self.reg_equation_latex = Latex(self.reg_equation)

        area_plot = plt.figure(figsize=(w, h))
        plt.plot(self.area_x, self.area_y, label=labelx, marker='^', linestyle='dashed')
        plt.plot(self.area_x, self.Y_pred, color='red', label=labely)
        # plt.gcf().set_size_inches(10,5) # otra opción para el tamaño de gráfico
        plt.suptitle(title, fontsize=14)
        plt.title(subtitle, fontsize=12)
        # plt.subtitle(subtitle)
        plt.xlabel(xlabel, fontsize=14)
        plt.ylabel(ylabel, fontsize=14)
        plt.text(int(max(self.area_x)/2), max(self.area_y)-max(self.area_y)*0.15, self.reg_equation, fontsize=12)
        plt.grid()
        plt.legend()
        # fig_area.set_visible(visible)
        # plt.xlim(range(len(area)))
        # plt.ylim(-0.05,5.0)
        # plt.show()
        self.figure_area = area_plot.get_figure()
        if visible == False:
            plt.close()
        else:
            plt.show()

        # self.area_plot = fig_area.gcf()
        # return fig_area, self.reg_equation

    @property
    def help(self):
        # self.data_plotter()
        # self.area_plotter()
        params = {'filter': '\'Filter\'   -> Filtro del nombre de archivos a cargar',
                'title': '\'Cinética\'   -> Titulo del gráfico',
                'subtitle': 'None   -> Subtitulo del gráfico',
                'index' : '\'Wavelength\' || None   -> Etiqueta de indinces de la tabla de datos',
                'xlabel': '\'Longitud de onda (nm)\'   -> Etiqueta del eje x',
                'ylabel': '\'Abosorbancia\'   -> Etiqueta del eje y',
                'x0' : '200   -> Valor inicial de x para graficar',
                'xf' : 'None   -> Vaor final de x para graficar',
                'y0' : '-0.05   -> Valor inicial de y para graficar',
                'yf' : '0.5   -> Valor final de y para graficar',
                'c0' : '0   -> Columna inicial para graficar',
                'cf' : 'None   -> Columna final para graficar',
                'width' : '23   -> Ancho del gráfico en cm',
                'height' : '15   -> Alto del gráfico en cm',
                'visible': 'True || False  -> Mostrar o no el gráfico '}
        params_area= {'title' : '\'Cinética\'   -> Titulo del gráfico de areas',
                      'subtitle' : '\'Area bajo la curva\'   -> Subtitulo del gráfico de areas',
                      'xlabel' : '\'Tiempo (h)\'   -> Eiqueta del eje x',
                      'ylabel' : '\'Area\'   -> Eiqueta del eje y',
                      'dx' : '1.5   -> Desplazamiento en x para el cálculo de areas',
                      'labelx' : '\'Area\'   -> Leyenda de los puntos de area',
                      'labely' : '\'y\'   -> Leyenda de la linea de regresión lineal',
                      'width' : '23   -> Ancho del gráfico de areas',
                      'height' : '15   -> Alto del gráfico de areas',
                      'dx' : '1.0   -> Paso de integración para el cálculo de areas',
                      'visible' : 'True   -> Mostrar o no el gráfico de areas'}
        print("""

INSTRUCCIONES DE USO:

    Creación del objeto spectroUV():
        Para crear el objeto asignamos a una variable dicho objeto:

        obj = SpectroUV()

        Una vez creado el objeto podemos cargar y graficar los archivos a analizar con
        la función plot(), la cual acepta un parámetro obligatorio:

        obj.plot(\'<filtro_de_archivos_a_graficar>\')

        Ejemplo:

        obj.plot('2021_01_')   -> Graficará todos los archivos en carpeta que empiecen con la cadena de caracteres '2021_01_'.

        \n""")

        print("""

    Propiedades:
    Con lo anterior ya podemos utilizar las siguientes propiedades y funciones:

        obj.help -> Muestra esta ayuda

        obj.frameall -> Muestra la tabla de datos completos creada

        obj.frame -> Mestra la tabla de datos creada con los parámetros x0, xf

        obj.figure -> Muestra el gráfico por default del espectro UV

        obj.figure_area -> Muestra el gráfico por default de las areas bajo la curva

        obj.reg_equation -> Muestra la ecuación de regreseión lineal del gráfico de areas

        obj.alfa -> Devuelve el valor de la ordenada al origen de bx + a

        obj.beta -> Devuelve el valor de la pendiente de bx + a

    Funciones:
    Las siguitenes funciones aceptan parámetros, separados por coma, para cambiar los
    de default:

        plot(): Genera gráfico del espectro

        obj.plot(<parámetro1>=<valor1> , <parámetro2>=<valor2>...)


        Parámetros por default:
        """)
        for key, value in params.items():
            print('\t \t {}={}'.format(key, value))

        print("""

        plot_area(): Genera gráfico de areas

        obj.plot_area(<parámetro1>=<valor1> , <parámetro2>=<valor2>...)


        Parámetros por default:
        """)
        for key, value in params_area.items():
            print('\t \t {}={}'.format(key, value))

        print("""

        save_plot(): Guarda la figura actual en formato .PDF o el formato de elección
         (jpg, png, svg)

        obj.save_plot(<obj.figure> ó <obj.figure_area>, 'nombre_de_figura.pdf')


        save_data(): Guarda el frame actual en formato .CSV

        obj.save_data('<nombre_de_archivo.csv>')
        """)





# from os import *
import natsort as nsrt
import numpy as np
from numpy import trapz
import h5py as h5
import matplotlib.pyplot as plt
import pandas as pd
from IPython.display import display, Latex, Math
import tkinter as tk
from tkinter import filedialog as fd
from laiiqa.helpers import *

class Ozonation:

    def plot(self, var='data',title='Cinética de Ozonización', subtitle=None, xlabel='Tiempo ', ylabel='$O_3$ [$g/Nm^3$]', label='Conc. $O_3$', width=23, height=15, x0=0, xf=None, y0=-0.5, yf=35.5, time='seg', units='g/nm3',grid=True, visible=True, dx=1.0, **kwargs):
        root = tk.Tk()
        root.withdraw()
        filetypes = (('MAT-Files', '*.mat'),)
        matfile = fd.askopenfilename(
                title='Seleccionar archivo .mat',
                filetypes=filetypes)

        matfile_name = matfile.rsplit('/', 1)[1]
        self.time = time
        wcm = cm2in(width)
        hcm = cm2in(height)

        if subtitle == None:
            subtitle = matfile_name

        f = h5.File(matfile,'r')
        data = np.array(f.get(var))
        self.frameall = pd.DataFrame(data)
        self.frameall = self.frameall.rename(columns={self.frameall.columns[0]:time, 1:'conc'})
        self.frameall.index = self.frameall[time]
        if time == 'min':
            self.frameall = self.frameall.rename(columns={self.frameall.columns[0]:time})
            self.frameall[time] = self.frameall[time]/60
            self.frameall.index = self.frameall[time]

        elif time == 'h':
            self.frameall = self.frameall.rename(columns={self.frameall.columns[0]:time})
            self.frameall[time] = self.frameall[time]/3600
            self.frameall.index = self.frameall[time]


        if xf == None:
            xf = max(self.frameall[time])

        self.frame = self.frameall[x0:xf]

        # fig = self.frame[self.x0:self.xf].plot(x=time, y='conc', figsize=[wcm,hcm], label=label, grid=grid, **kwargs)
        fig = self.frame.plot(x=time, y='conc', figsize=[wcm,hcm], label=label, grid=grid, **kwargs)
        plt.suptitle(title, fontsize=14)
        plt.title(subtitle, fontsize=12)
        # fig.set_title(subtitle, fontsize=12)
        fig.set_xlim(x0, xf)
        fig.set_ylim(y0, yf)
        fig.set_xlabel(xlabel+f'({time})', fontsize=12)
        fig.set_ylabel(ylabel, fontsize=12)
        self.figure = fig.get_figure()
        # plt.show()

        self.residual = trapz(x=self.frame[time][x0:xf], y=self.frame['conc'][x0:xf], dx=dx)
        self.consumido = (max(self.frame[time][x0:xf])*max(self.frame['conc'][x0:xf]) - self.residual)


        if time == 'seg':
            self.residual = self.residual/60
            self.consumido = self.consumido/60
        elif time == 'h':
            self.residual = self.residual*60
            self.consumido = self.consumido*60

        # Agregar la opción de unidades g/Nm3 o g/L
        if units == 'g/nm3':
            self.residual_print = r'Ozono residual = {0:.2f} g/Nm^3 en {1:.0f} {2}'.format(float(self.residual), max(self.frame[time][x0:xf])-x0,time)

            self.residual_latex = Latex(r'Ozono residual = $${0:.2f}~g/Nm^3$$ en {1:.0f} {2}'.format(float(self.residual),max(self.frame[time][x0:xf])-x0,time))

            self.consumido_print = r'Ozono consumido = {0:.2f} g/Nm^3 en {1:.0f} {2}'.format(float(self.consumido),max(self.frame[time][x0:xf])-x0,time)

            self.consumido_latex = Latex(r'Ozono consumido = $${0:.2f}~g/Nm^3$$ en {1:.0f} {2}'.format(float(self.consumido),max(self.frame[time][x0:xf])-x0,time))

            self.total = self.residual + self.consumido
            self.total_print = f'Total ozono generado = {self.total:.2f} g/Nm^3 en {max(self.frame[time][x0:xf])-x0:.0f} {time}'
            self.total_latex = Latex(f'Total ozono generado = $${self.total:.2f}~g/Nm^3$$ en {max(self.frame[time][x0:xf])-x0:.0f} {time}')

        if units == 'g/l':
            self.residual = self.residual/1000
            self.consumido = self.consumido/1000

            self.residual_print = r'Ozono residual = {0:.2f} g/L en {1:.0f} {2}'.format(float(self.residual), max(self.frame[time][x0:xf])-x0,time)

            self.residual_latex = Latex(r'Ozono residual = $${0:.2f}~g/L$$ en {1:.0f} {2}'.format(float(self.residual),max(self.frame[time][x0:xf])-x0,time))

            self.consumido_print = r'Ozono consumido = {0:.2f} g/L en {1:.0f} {2}'.format(float(self.consumido),max(self.frame[time][x0:xf])-x0,time)

            self.consumido_latex = Latex(r'Ozono consumido = $${0:.2f}~g/L$$ en {1:.0f} {2}'.format(float(self.consumido),max(self.frame[time][x0:xf])-x0,time))

            self.total = self.residual + self.consumido
            self.total_print = f'Total ozono generado = {self.total:.2f} g/L en {max(self.frame[time][x0:xf])-x0:.0f} {time}'
            self.total_latex = Latex(f'Total ozono generado = $${self.total:.2f}~g/L$$ en {max(self.frame[time][x0:xf])-x0:.0f} {time}')

        if visible == False:
            plt.close()
        else:
            plt.show()



    def join(self, frames=list(), labels=list(),title='Cinética de Ozonización', subtitle='', xlabel='Tiempo ', ylabel='$O_3$ [$g/Nm^3$]', width=23, height=15, x0=0, xf=None, y0=-0.5, yf=35.5, grid=True, visible=True, dx=1.0,**kwargs):
        wcm = cm2in(width)
        hcm = cm2in(height)
        # fig1 = plt.figure()
        fig, ax = plt.subplots(figsize=[wcm,hcm])
        for frame,label in zip(frames,labels):
            frame.plot(y='conc', ax=ax, label=label)

        # time = frames[0].columns[0]
        plt.suptitle(title, fontsize=14)
        plt.title(subtitle, fontsize=12)
        plt.xlim(x0, xf)
        plt.ylim(y0, yf)
        plt.xlabel(xlabel+f'({self.time})', fontsize=12)
        plt.ylabel(ylabel, fontsize=12)
        plt.grid(grid)
        self.joined_plots = fig.get_figure()
        if visible == False:
            plt.close()
        else:
            plt.show()
            # return self.joined_plots



import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
from scipy.interpolate import interp1d
import tkinter as tk
from tkinter import filedialog as fd
from laiiqa.helpers import *


class RawData:

    # frame = pd.DataFrame()

    # def ___init__(self, data):
        # self.data = data
        # self.raw_data(self.data)
        # return self.frame

    # def raw_data(self, data, showframe=False):
    #     # self.data = data
    #     self.frame = pd.DataFrame()
    #     for i in range(len(data)):
    #         self.frame[list(self.data)[i]] = self.data[list(self.data)[i]]
    #
    #     # self.frame.index = self.frame[self.frame.columns[0]]
    #     if showframe == True:
    #         return self.frame

    # @property
    # def frame(self):
    #     return self.frame

    # @frame.setter
    # def frame(self):
    #     return self.frame

    # , secondary_y=False, subplots=False):
    def plot(self, data, title='title=\'Titulo\'', subtitle='subtitle=\'Subtitulo\'', xlabel='xlabel=\'Xlabel\'', ylabel='ylabel=\'Ylabel\'', ylabel2='ylabel2=\'Ylabel 2\'', x=None, width=23, height=15, secondary_y=False, subplots=False, grid=True, interpolation=False, interp='cubic', steps=200, **kwargs):
        self.data = data
        w = cm2in(width)
        h = cm2in(height)

        self.frame = pd.DataFrame()
        for i in range(len(data)):
            self.frame[list(self.data)[i]] = self.data[list(self.data)[i]]


        self.frame.index = self.frame[self.frame.columns[0]]

        if interpolation == True:
            func = dict()
            for i in range(1, len(self.frame.columns)):
                func[i] = interp1d(
                    self.frame.index, self.frame[self.frame.columns[i]], kind=interp)

            self.frame_intp = pd.DataFrame()
            indx = np.linspace(0, max(self.frame[self.frame.columns[0]]), steps)

            for j in range(1, len(self.frame.columns)):
                self.frame_intp[self.frame.columns[j]] = func[j](indx)

            self.frame_intp.index = indx
            if subplots == False:
                fig = self.frame_intp.plot(figsize=(w, h), secondary_y=secondary_y, grid=grid, **kwargs)
                plt.suptitle(title, fontsize=14)
                fig.set_title(subtitle, fontsize=12)
                fig.set_xlabel(xlabel, fontsize=12)
                fig.set_ylabel(ylabel, fontsize=12)
                if secondary_y != False:
                    ylabel2 = secondary_y
                    fig.right_ax.set_ylabel(ylabel2, fontsize=12)

                self.figure = fig.get_figure()
                plt.close()
                return self.figure

            else: #subplots == True:
                color = plt.rcParams["axes.prop_cycle"]()
                fig, axes = plt.subplots(nrows=3, ncols=1, sharex=True)
                for n in range(0,len(self.frame_intp.columns)):
                    c = next(color)['color']
                    axes[n].plot(self.frame_intp[self.frame_intp.columns[n]], color=c)
                    axes[n].legend([self.frame_intp.columns[n]])
                    axes[n].grid(grid)

                fig.suptitle(title)
                fig.supxlabel(xlabel)
                fig.supylabel(ylabel)
                self.figure = fig.get_figure()
                plt.close()
                return self.figure
        else: # interpolation == False
            if subplots == False:
                fig = self.frame.plot(x=x, figsize=(w, h), secondary_y=secondary_y, grid=grid, **kwargs)
                plt.suptitle(title, fontsize=14)
                fig.set_title(subtitle, fontsize=12)
                fig.set_xlabel(xlabel, fontsize=12)
                fig.set_ylabel(ylabel, fontsize=12)
                if secondary_y != False:
                    ylabel2 = secondary_y
                    fig.right_ax.set_ylabel(ylabel2, fontsize=12)

                self.figure = fig.get_figure()
                plt.close()
                return self.figure

            else: #subplots == True:
                color = plt.rcParams["axes.prop_cycle"]()
                fig, axes = plt.subplots(nrows=3, ncols=1, sharex=True)
                for n in range(0,len(self.frame.columns)):
                    c = next(color)['color']
                    axes[n].plot(self.frame[self.frame.columns[n]], color=c)
                    axes[n].legend([self.frame.columns[n]])
                    axes[n].grid(grid)

                fig.suptitle(title)
                fig.supxlabel(xlabel)
                fig.supylabel(ylabel)
                self.figure = fig.get_figure()
                plt.close()
                return self.figure
            # def raw_plotter(self, frame, suptitle='Cinética de Crecimiento', title='',xlabel='Tiempo (h)', ylabel='DO (600nm)', ylabel2='DO (unidades Bug)',c0=1, cf=None,grid=True, linestyle='-', xsize=23, ysize=15, subplots=False, sharex=False,sharey=False):#, time):
            #
            #     # frame.index = frame[frame.columns[0]]
            #     if cf == None:
            #         ycolumn = frame.columns[1:]
            #     else:
            #         ycolumn = frame.columns[1,cf]
            #
            #     # fig= plt.subplots()
            #     fig = frame.plot(x=frame.columns[0], y=ycolumn, grid=grid, linestyle=linestyle,figsize=(cm2in(xsize),cm2in(ysize)), subplots=subplots, sharex=sharex, sharey=sharey)#,xticks=frame[frame.columns[0]])
            #     # fig.plot(frame[frame.columns[0]],frame[frame.columns[3]], label='Promedio')
            #     plt.suptitle(suptitle, fontsize=14)
            #     plt.title(title, fontsize=12)
            #     plt.xlabel(xlabel, fontsize=12)
            #     plt.ylabel(ylabel, fontsize=12)
            #     plt.legend()
            #     # plt.show()
            #     return frame



from setuptools import setup, find_packages

with open('README.md', encoding="utf-8") as f:
    long_description = f.read()

setup(
name = 'laiiqa-lab-utilities',
version = '0.1.0',
description = 'Package for ozonation, spectro uv and bioreaction data analysis files for the LAIIQA laboratory (ESIQIE - IPN).',
long_description = long_description,
long_description_content_type = 'text/markdown',
license = 'MIT License',
author = 'F. Javier Morales M.',
author_email = 'fmoralesm87@gmail.com',
url = '',
python_requires = '>=3.7',
install_requires = [
    'natsort',
    'numpy',
    'pandas',
    'matplotlib',
    'h5py',
    'sklearn',
    'IPython'
],
packages = find_packages(),
classifiers = [
    'Development Status :: 2 - Pre-Alpha',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.0',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Operating System :: OS Independent',
    'Operating System :: Microsoft :: Windows',
    'Operating System :: MacOS',
    'Operating System :: POSIX :: Linux',
    'Topic :: Scientific/Engineering',
    'Intended Audience :: Science/Research',
    'Intended Audience :: Developers',
    'Intended Audience :: Education'
    ]
)



from os import getcwd, listdir, chdir
import natsort as nsrt
import pandas as pd
import matplotlib.pyplot as plt
import tkinter as tk
from tkinter import filedialog as fd

figuras = r'C:\Users\javne\Dropbox\Tesis Maestria Javier\Tesis\Figuras'
figuras_resultados = r'C:\Users\javne\Dropbox\Tesis Maestria Javier\Tesis\Figuras\resultados'
experimentacion = r'C:\Users\javne\Dropbox\Tesis Maestria Javier\Tesis\Experimentacion'
experimentacion_ozonaciones = r'C:\Users\javne\Dropbox\Tesis Maestria Javier\Tesis\Experimentacion\O3onaciones'
experimentacion_espectrouv = r'C:\Users\javne\Dropbox\Tesis Maestria Javier\Tesis\Experimentacion\EspectroUV'

def where():
    w = getcwd()
    return print(w), nsrt.natsorted(listdir(w))



def cd(folder):
    chdir(folder)
    d = getcwd()
    return print(d), nsrt.natsorted(listdir(d))



def cm2in(value):
    return value/2.54



def save_plot(fig, name):
    fig.savefig(name)



def save_data(self, frame, name):
    frame.to_csv(name, index=frame.index)
    # frame.to_csv(name, index=self.index)

# def join_plots(frames=list(), labels=list(),title='Cinética de Ozonización', subtitle='', xlabel='Tiempo ', ylabel='$O_3$ [$g/Nm^3$]', width=23, height=15, x0=0, xf=None, y0=-0.5, yf=35.5, time='seg', grid=True, visible=True, dx=1.0, **kwargs):
#     wcm = cm2in(width)
#     hcm = cm2in(height)
#     fig, ax = plt.subplots(figsize=[wcm,hcm])
#     ax.grid(grid)
#     for frame,label in zip(frames,labels):
#         frame.plot(y='conc', ax=ax, label=label)
#
#     plt.suptitle(title, fontsize=14)
#     plt.title(subtitle, fontsize=12)
#     plt.xlim(x0, xf)
#     plt.ylim(y0, yf)
#     plt.xlabel(xlabel+f'({time})', fontsize=12)
#     plt.ylabel(ylabel, fontsize=12)
#     plt.close()
#     joined_plots = fig.get_figure()
#     return joined_plots
